@@ -4,7 +4,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 1;
 __END__
@@ -13,12 +13,10 @@ __END__
 
 =head1 NAME
 
-JSV - JSON Schema implementation of Perl
+JSV - A perl implementation of JSON Schema (draft-04) validator
 
 =head1 SYNOPSIS
 
-    use JSV;
-
 =head1 DESCRIPTION
 
 See e.g. L<JSV::Validator>
